--[[
    CandyBarTimerRendererLib
    Copyright (C) 2008 Gael Lalire
    Contact: gael.lalire@laposte.net

    CandyBarTimerRendererLib is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    CandyBarTimerRendererLib is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with CandyBarTimerRendererLib.  If not, see <http://www.gnu.org/licenses/>.
--]]

local candyBarTimerRendererLib = LibStub:NewLibrary("CandyBarTimerRendererLib-1.0", 1);
if not candyBarTimerRendererLib then
  return;
end

-- begin import
local factoryLib = LibStub("FactoryLib-1.0");
local Factory = factoryLib.Factory;
local timerLib = LibStub("TimerLib-1.0");
local TimerRendererFactory = timerLib.TimerRendererFactory;
local environmentLib = LibStub("EnvironmentLib-1.0");
local environment = environmentLib.environment;
-- end import


--[[
  The CandyBarTimerRenderer class.
--]]

-- CandyBarTimerRenderer extends TimerRenderer
local CandyBarTimerRenderer, CandyBarTimerRendererFactory, candyBarTimerRendererFactory = Factory.CreateType(TimerRendererFactory);
candyBarTimerRendererLib.CandyBarTimerRenderer = CandyBarTimerRenderer;
candyBarTimerRendererLib.CandyBarTimerRendererFactory = CandyBarTimerRendererFactory;
candyBarTimerRendererLib.candyBarTimerRendererFactory = candyBarTimerRendererFactory;

CandyBarTimerRenderer.LEFT_DIRECTION = 1;
CandyBarTimerRenderer.RIGHT_DIRECTION = 2;

-- ignore name (1st arg)
function CandyBarTimerRenderer:StartTimer(_, duration, texture, target, count, tickFrequency, tickStart)
  if not self.enabled then
    return;
  end
  self.target = target;
  self:SetCount(count);
  self.candyBar:SetCandyBarIcon(self.name, texture);
  self.candyBar:SetTime(self.name, duration);
  self.candyBar:Start(self.name);
end

function CandyBarTimerRenderer:StopTimer()
  self.candyBar:Stop(self.name);
end

function CandyBarTimerRenderer:SetCount(count)
  if self.target then
    if count ~= -1 then
      self.candyBar:SetText(self.name, count..". "..self.target);
    else
      self.candyBar:SetText(self.name, self.target);
    end
  end
end

function CandyBarTimerRenderer:SetDirection(direction)
  if direction==self.LEFT_DIRECTION then
    -- self.candyBar:SetCandyBarReversed(self.name, false);
  elseif direction==self.RIGHT_DIRECTION then
    -- self.candyBar:SetCandyBarReversed(self.name, true);
  end
end

function CandyBarTimerRenderer:SetPosition(parent, left, top)
  self.candyBar:SetCandyBarPoint(self.name, "LEFT", parent, "TOPLEFT", left, -top);
end

function CandyBarTimerRenderer:SetEnabled(enabled)
  if enabled ~= self.enabled then
    self.enabled = enabled;
    if not enabled then
      self.candyBar:Stop(self.name);
    end  
  end
end

--[[
  The CandyBarTimerRendererFactory class.
--]]

-- scale did not work
function CandyBarTimerRendererFactory:Create(name, scale)
  candyBarTimerRenderer = self:NewInstance();

  candyBarTimerRenderer.enabled = true;
  candyBarTimerRenderer.name = name;
  CandyBarTimerRenderer.candyBar:Register(name, 1, "", nil, "green", "red");
  candyBarTimerRenderer:SetPosition(UIParent, 0, 0);
  -- self.candyBar:SetCandyBarScale(name, scale);
  return candyBarTimerRenderer;
end

function CandyBarTimerRendererFactory:VARIABLES_LOADED()
  CandyBarTimerRenderer.candyBar = {};
  setmetatable(CandyBarTimerRenderer.candyBar, {__index = LibStub("CandyBar-2.0")});
  environment:UnregisterEvent("VARIABLES_LOADED", self);
end

environment:RegisterEvent("VARIABLES_LOADED", candyBarTimerRendererFactory);


